@@ -1,6 +1,6 @@
 ;;; sb-itmedia.el --- shimbun backend for ITmedia -*- coding: iso-2022-7bit -*-
 
-;; Copyright (C) 2004 Yuuichi Teranishi <teranisi@gohome.org>
+;; Copyright (C) 2004, 2005 Yuuichi Teranishi <teranisi@gohome.org>
 
 ;; Author: TSUCHIYA Masatoshi <tsuchiya@namazu.org>,
 ;;         Yuuichi Teranishi  <teranisi@gohome.org>
@@ -40,13 +40,15 @@
 (defvar shimbun-itmedia-url "http://www.itmedia.co.jp/")
 
 (defvar shimbun-itmedia-group-alist
-  (let ((template "<a href=\"/\\(\\(%s\\)/\\([0-9][0-9]\\)\\([0-9][0-9]\\)\
-/\\([0-9][0-9]\\)/\\([^\\.\">]+\\)\\.html\\)[^>]*>"))
+  (let ((template (concat "<a href=\""
+			  "\\(" (regexp-quote shimbun-itmedia-url) "\\|/\\)"
+			  "\\(\\(%s\\)/\\([0-9][0-9]\\)\\([0-9][0-9]\\)\
+/\\([0-9][0-9]\\)/\\([^\\.\">]+\\)\\.html\\)[^>]*>")))
     `(("anchordesk" "anchordesk"
        ,(format template "anchordesk/articles")
        "$B!N(B[^ ]* \\([0-9]+:[0-9]+\\)$B!O(B")
       ("bursts" "news/bursts"
-       ,(format template "news/articles")
+       ,(format template "enterprise/articles\\|news/articles")
        "$B!N(B[^ ]* \\([0-9]+:[0-9]+\\)$B!O(B")
       ("business" "news/business"
        ,(format template "news/articles")
@@ -55,7 +57,7 @@
        ,(format template "enterprise/articles")
        "$B!N(B[^ ]* \\([0-9]+:[0-9]+\\)$B!O(B")
       ("games" "games/news"
-       ,(format template "games/gsnews")
+       ,(format template "games/articles")
        nil)
       ("lifestyle" "lifestyle"
        ,(format template "lifestyle/articles")
@@ -101,6 +103,7 @@ R[TQ[*i0d##D=I3|g`2yr@sc<pK1SB
 	 (group (shimbun-current-group-internal shimbun))
 	 (url-regexp (nth 2 (assoc group shimbun-itmedia-group-alist)))
 	 (time-regexp (nth 3 (assoc group shimbun-itmedia-group-alist)))
+	 (table '(("$B!'(B" ":") ("$B!N(B" "[") ("$B!O(B" "]")))
 	 next headers)
     (while (search-forward "\r" nil t)
       (replace-match "\n"))
@@ -111,44 +114,48 @@ R[TQ[*i0d##D=I3|g`2yr@sc<pK1SB
 		 (setq next nil)
 		 (goto-char (match-end 0)))
 	     (re-search-forward url-regexp nil t))
-      (unless (string= "index" (match-string 6))
-	(let* ((url (match-string 1))
-	       (year (+ 2000 (string-to-number (match-string 3))))
-	       (month (string-to-number (match-string 4)))
-	       (day (string-to-number (match-string 5)))
-	       (id (format "<%s%s%s%s%%%s>"
-			   (match-string 3)
-			   (match-string 4)
-			   (match-string 5)
-			   (match-string 6)
-			   group))
-	       (subject (mapconcat 'identity
-				   (split-string
-				    (buffer-substring
-				     (match-end 0)
-				     (progn
-				       (search-forward "</A>" nil t)
-				       (point)))
-				    "<[^>]+>")
-				   ""))
-	       time)
-	  (while (string-match "\n" subject)
-	    (setq subject (concat (substring subject 0 (match-beginning 0))
-				  (substring subject (match-end 0)))))
-	  (when time-regexp
-	    (setq next (point)
-		  next (when (re-search-forward url-regexp nil t)
-			 (goto-char next)
-			 (match-data))
-		  time (when (re-search-forward time-regexp (car next) t)
-			 (match-string 1))))
-	  (push (shimbun-create-header
-		 0 subject
-		 (shimbun-from-address shimbun)
-		 (shimbun-make-date-string year month day time)
-		 id  "" 0 0
-		 (concat shimbun-itmedia-url url))
-		headers))))
+      (unless (string= "index" (match-string 7))
+	(let ((url (match-string 2))
+	      (year (+ 2000 (string-to-number (match-string 4))))
+	      (month (string-to-number (match-string 5)))
+	      (day (string-to-number (match-string 6)))
+	      (id (format "<%s%s%s%s%%%s>"
+			  (match-string 4)
+			  (match-string 5)
+			  (match-string 6)
+			  (match-string 7)
+			  group))
+	      (subject (mapconcat
+			(lambda (s)
+			  (dolist (e table s)
+			    (setq s (apply 'shimbun-replace-in-string s e))))
+			(delete
+			 ""
+			 (split-string
+			  (buffer-substring (match-end 0)
+					    (progn
+					      (search-forward "</A>" nil t)
+					      (point)))
+			  "[\t\n ]*<[^>]+>[\t\n ]*\\|[\t\n $B!!(B]+"))
+			" "))
+	      time)
+	  (unless (zerop (length subject))
+	    (setq subject (shimbun-replace-in-string
+			   subject " ?\\([$B!H!I!J!K!V!W(B]\\) ?" "\\1"))
+	    (when time-regexp
+	      (setq next (point)
+		    next (when (re-search-forward url-regexp nil t)
+			   (goto-char next)
+			   (match-data))
+		    time (when (re-search-forward time-regexp (car next) t)
+			   (match-string 1))))
+	    (push (shimbun-create-header
+		   0 subject
+		   (shimbun-from-address shimbun)
+		   (shimbun-make-date-string year month day time)
+		   id  "" 0 0
+		   (concat shimbun-itmedia-url url))
+		  headers)))))
     (shimbun-sort-headers headers)))
 
 (defun shimbun-itmedia-clean-text-page ()
